str_width

Function str_width 

pub fn str_width(s: &str) -> usize
Returns the width of a str s, breaking the string down into multiple graphemes. This takes into account some things like joiners when calculating width.